'use strict';
Object.defineProperty(exports, '__esModule', {value: true});
const tslib_1 = require('tslib');
const react_native_1 = require('react-native');
const React = tslib_1.__importStar(require('react'));
const utils_1 = require('./utils');
const useFocusState_1 = tslib_1.__importDefault(require('./useFocusState'));
const CodeField_styles_1 = tslib_1.__importDefault(
  require('./CodeField.styles'),
);
const DEFAULT_CELL_COUNT = 4;
const CodeField = (
  {
    rootStyle,
    textInputStyle,
    onBlur,
    onFocus,
    value,
    renderCell,
    cellCount = DEFAULT_CELL_COUNT,
    RootProps = {},
    RootComponent = react_native_1.View,
    ...rest
  },
  ref,
) => {
  const [isFocused, handleOnBlur, handleOnFocus] = useFocusState_1.default({
    onBlur,
    onFocus,
  });
  const cells = utils_1
    .getSymbols(value || '', cellCount)
    .map((symbol, index, symbols) => {
      const isFirstEmptySymbol = symbols.indexOf('') === index;
      return renderCell({
        index,
        symbol,
        isFocused: isFocused && isFirstEmptySymbol,
      });
    });
  return React.createElement(
    RootComponent,
    Object.assign({}, RootProps, {
      style: utils_1.getStyle(CodeField_styles_1.default.root, rootStyle),
    }),
    cells,
    React.createElement(
      react_native_1.TextInput,
      Object.assign(
        {
          caretHidden: true,
          disableFullscreenUI: true,
          spellCheck: false,
          autoCorrect: false,
          blurOnSubmit: false,
          clearButtonMode: 'never',
          autoCapitalize: 'characters',
          underlineColorAndroid: 'transparent',
          maxLength: cellCount,
        },
        rest,
        {
          value: value,
          onBlur: handleOnBlur,
          onFocus: handleOnFocus,
          style: utils_1.getStyle(
            CodeField_styles_1.default.textInput,
            textInputStyle,
          ),
          ref: ref,
        },
      ),
    ),
  );
};
exports.default = React.forwardRef(CodeField);
